@@ -70,6 +70,8 @@ import click
               help='Cache existing result')
 @click.option('--exclude', default="", show_default=True,
               help='Exclude NPs (wildcard is accepted)')
+@click.option('--constrained_only/--any_nuis', default=True, show_default=True,
+              help='Whether to include constrained nuisance parameters only')
 def run_pulls(**kwargs):
     """
     Tool for computing NP pulls and impacts
@@ -161,6 +163,8 @@ def plot_pulls(**kwargs):
               help='POI to scan. If not specified, the first POI from the workspace is used.')
 @click.option('-d', '--data', 'data_name', default='combData', show_default=True,
               help='Name of dataset')
+@click.option('--asimov_data_name', 'asimov_data_name', default=None,
+              help='If given, use custom background asimov dataset instead of generating on the fly.')
 @click.option('-o', '--outname', default='limits.json', show_default=True,
               help='Name of output')
 @click.option('--blind/--unblind', 'do_blind', default=True, show_default=True,
@@ -169,6 +173,8 @@ def plot_pulls(**kwargs):
               help='CL value to use')
 @click.option('--precision', default=0.005, show_default=True,
               help='precision in mu that defines iterative cutoff')
+@click.option('--adjust_fit_range/--keep_fit_range', default=True, show_default=True,
+              help='whether to adjust the fit range to median limit +- 5 sigma for observed fit')
 @click.option('--do_tilde/--no_tilde', default=True, show_default=True,
               help='bound mu at zero if true and do the \tilde{q}_{mu} asymptotics')
 @click.option('--predictive_fit/--no_predictive_fit', default=True, show_default=True,
