@@ -14,4 +14,7 @@ from quickstats.components.analysis_base import AnalysisBase
 from quickstats.components.param_parser import ParamParser
 from quickstats.components.roo_inspector import RooInspector
 from quickstats.components.extended_rfile import ExtendedRFile
-from quickstats.components.signal_modelling import SignalModelling
\ No newline at end of file
+from quickstats.components.signal_modelling import SignalModelling
+
+import ROOT
+ROOT.gROOT.SetBatch()
\ No newline at end of file
