@@ -9,6 +9,7 @@ import math
 import numpy as np
 import ROOT
 
+import quickstats
 from quickstats.components import AbstractObject
 
 class ExtendedMinimizer(AbstractObject):
@@ -143,27 +144,31 @@ class ExtendedMinimizer(AbstractObject):
                 self.stdout.info(f"INFO: Using the range \"{range_name}\" for NLL calculation")
         if dataset is None:
             dataset = self.data
-        if len(nll_commands) <= 6:
+        
+        if quickstats.root_version >= (6, 26, 0):            
             nll = self.pdf.createNLL(dataset, *nll_commands)
-        # bug: can't have more than 6 arguments
-        elif len(nll_commands) == 7:
-            reduced_command_list = [i for i in nll_commands if i.GetName() != 'NumCPU']
-            self.stdout.warning("WARNING: Maximum number (6) of NLL commands reached. "
-                                "Will remove `NumCPU` from the command list")
-            if len(reduced_command_list) <= 6:
-                nll = self.pdf.createNLL(dataset, *reduced_command_list)
-            else:
-                raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
-        elif len(nll_commands) == 8:
-            reduced_command_list = [i for i in nll_commands if i.GetName() not in ['NumCPU', 'IntegrateBins']]
-            self.stdout.warning("WARNING: Maximum number (6) of NLL commands reached. "
-                                "Will remove `NumCPU` and `IntegrateBins` from the command list")
-            if len(reduced_command_list) <= 6:
-                nll = self.pdf.createNLL(dataset, *reduced_command_list)
-            else:
-                raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
         else:
-            raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
+            if len(nll_commands) <= 6:
+                nll = self.pdf.createNLL(dataset, *nll_commands)
+            # bug: can't have more than 6 arguments
+            elif len(nll_commands) == 7:
+                reduced_command_list = [i for i in nll_commands if i.GetName() != 'NumCPU']
+                self.stdout.warning("WARNING: Maximum number (6) of NLL commands reached. "
+                                    "Will remove `NumCPU` from the command list")
+                if len(reduced_command_list) <= 6:
+                    nll = self.pdf.createNLL(dataset, *reduced_command_list)
+                else:
+                    raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
+            elif len(nll_commands) == 8:
+                reduced_command_list = [i for i in nll_commands if i.GetName() not in ['NumCPU', 'IntegrateBins']]
+                self.stdout.warning("WARNING: Maximum number (6) of NLL commands reached. "
+                                    "Will remove `NumCPU` and `IntegrateBins` from the command list")
+                if len(reduced_command_list) <= 6:
+                    nll = self.pdf.createNLL(dataset, *reduced_command_list)
+                else:
+                    raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
+            else:
+                raise RuntimeError("due to a bug in ROOT, nll can not have more than 6 arguments")
         return nll
             
     def create_nll(self, nll_commands:List["ROOT.RooCmdArg"]=None, 
@@ -194,7 +199,8 @@ class ExtendedMinimizer(AbstractObject):
             if self.config['max_iters'] != -1:
                 self.minimizer.setMaxIterations(self.config['max_iters'])
     
-    def construct_nll_commands(self, constrain=None, global_observables=None, **kwargs):
+    def construct_nll_commands(self, constrain=None, global_observables=None, 
+                               conditional_observables=None, **kwargs):
         commands = []
         if 'num_cpu' in kwargs:
             commands.append(ROOT.RooFit.NumCPU(kwargs['num_cpu'], 3))
@@ -207,12 +213,14 @@ class ExtendedMinimizer(AbstractObject):
         if ('batch_mode' in kwargs) and hasattr(ROOT.RooFit, "BatchMode"):
             commands.append(ROOT.RooFit.BatchMode(kwargs['batch_mode']))
         if ('int_bin_precision' in kwargs) and hasattr(ROOT.RooFit, "IntegrateBins"):
-            commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))
+            commands.append(ROOT.RooFit.IntegrateBins(kwargs['int_bin_precision']))
         if constrain is not None:
             commands.append(ROOT.RooFit.Constrain(constrain))
-            self.stdout.warning("WARNING: Use of `Constrain` option from createNLL is not recommended", "red")
+            #self.stdout.warning("WARNING: Use of `Constrain` option from createNLL is not recommended", "red")
         if global_observables is not None:
             commands.append(ROOT.RooFit.GlobalObservables(global_observables))
+        if conditional_observables is not None:
+            commands.append(ROOT.RooFit.ConditionalObservables(conditional_observables))
         command_dict = {}
         for command in commands:
             command_dict[command.GetName()] = command
@@ -229,9 +237,11 @@ class ExtendedMinimizer(AbstractObject):
             command_dict[command.GetName()] = command
         self.nll_commands = command_dict
         
-    def configure_nll(self, constrain=None, global_observables=None, update:bool=False, **kwargs):
+    def configure_nll(self, constrain=None, global_observables=None, conditional_observables=None, 
+                      update:bool=False, **kwargs):
         command_dict = self.construct_nll_commands(constrain=constrain, 
                                                    global_observables=global_observables,
+                                                   conditional_observables=conditional_observables,
                                                    **kwargs)
         if update:
             self.nll_commands.update(command_dict)
