@@ -94,6 +94,14 @@ class ExtendedModel(AbstractObject):
     def observables(self):
         return self._observables
     
+    @property
+    def category(self):
+        return self._category
+    
+    @property
+    def data_cat(self):
+        return self._data_cat
+    
     @property
     def initial_snapshots(self):
         return self._initial_snapshots
@@ -261,6 +269,7 @@ class ExtendedModel(AbstractObject):
             self.stdout.warning("WARNING: No nuisance parameters found in the workspace. "
                                 "An empty set will be loaded by default.")
             nuisance_parameters = ROOT.RooArgSet()
+            model_config.SetNuisanceParameters(nuisance_parameters)
         else:
             self.stdout.info('INFO: Loaded nuisance parameters from model config')
                 
@@ -285,6 +294,18 @@ class ExtendedModel(AbstractObject):
             raise RuntimeError('Failed to load observables')     
         self.stdout.info('INFO: Loaded observables from model config')
         
+        # get categories in case pdf is RooSimultaneous
+        if pdf.ClassName() == "RooSimultaneous":
+            category = pdf.indexCat()
+        else:
+            category = None
+        
+        # split dataset according to categories
+        if category is not None:
+            data_cat = data.split(category, True)
+        else:
+            data_cat = None
+        
         self._file                = file
         self._workspace           = ws
         self._model_config        = model_config
@@ -294,6 +315,8 @@ class ExtendedModel(AbstractObject):
         self._global_observables  = global_observables
         self._pois                = pois
         self._observables         = observables
+        self._category            = category
+        self._data_cat            = data_cat
                           
         # Load snapshots
         self.load_snapshots(self.initial_snapshots)
@@ -613,7 +636,9 @@ class ExtendedModel(AbstractObject):
             for nuis in constrained_nuis:
                 nuis.setConstant(1)
     
-    def get_all_constraints(self):
+    def get_all_constraints(self, pdf:Optional[ROOT.RooAbsPdf]=None):
+        if pdf is None:
+            pdf = self.pdf
         all_constraints = ROOT.RooArgSet()
         cache_name = "CACHE_CONSTR_OF_PDF_{}_FOR_OBS_{}".format(self.pdf.GetName(), 
                      ROOT.RooNameSet(self.data.get()).content())                 
@@ -625,7 +650,7 @@ class ExtendedModel(AbstractObject):
             # load information needed to determine attributes from ModelConfig 
             obs = self.observables.Clone()
             nuis = self.nuisance_parameters.Clone()
-            all_constraints = self.pdf.getAllConstraints(obs, nuis, ROOT.kFALSE)
+            all_constraints = pdf.getAllConstraints(obs, nuis, ROOT.kFALSE)
             
         # take care of the case where we have a product of constraint terms
         temp_all_constraints = ROOT.RooArgSet(all_constraints.GetName())
@@ -1263,47 +1288,8 @@ class ExtendedModel(AbstractObject):
         return category_map
     
     @staticmethod
-    def get_dataset_values(dataset):
-        parameters = dataset.get()
-        observables = ROOT.RooArgSet()
-        category = None
-        for p in parameters:
-            if isinstance(p, ROOT.RooRealVar):
-                observables.add(p)
-            elif isinstance(p, ROOT.RooCategory):
-                if category is None:
-                    category = p
-                else:
-                    raise RuntimeError("multiple RooCategory instances found in the dataset")
-            else:
-                raise RuntimeError(f"unknown object type \"{type(p)}\" found in the dataset")
-        """
-        n_entries = dataset.numEntries()
-        result = {}
-        # only available after ROOT 6.24
-        #data_buffer = ROOT.RooBatchCompute.RunContext()
-        #dataset.getBatches(data_buffer, 0, n_entries)
-        #for obs in observables:
-        #    obs_name = obs.GetName()
-        #    data = np.asarray(data_buffer.getBatch(obs))
-        #    result[obs_name] = data
-        for obs in observables:
-            obs_name = obs.GetName()
-            result[obs_name] = np.empty(n_entries)
-            for i in range(n_entries):
-                dataset.get(i)
-                result[obs_name][i] = obs.getVal()
-        result['weight'] = np.asarray(dataset.getWeightBatch(0, n_entries))
-        if category is not None:
-            result['label'] = np.empty(n_entries, dtype=object)
-            result['index'] = np.empty(n_entries)
-            for i in range(n_entries):
-                dataset.get(i)
-                result['label'][i] = category.getLabel()
-                result['index'][i] = category.getIndex()
-        """
-        result = RooDataSet.extract_category_data(dataset, observables, category)
-        return result
+    def get_dataset_values(dataset:ROOT.RooDataSet):
+        return RooDataSet.to_numpy(dataset)
     
     def _get_new_binnings(self, bins:Optional[Union[Dict, int]]=None):
         category_map = self.get_category_map()
@@ -1565,6 +1551,11 @@ class ExtendedModel(AbstractObject):
             variables.remove(nuisance_parameters)
             variables.remove(global_observables)
             variables.remove(observables)
+        elif _variable_type == WSVariables.CORE:
+            variables = ROOT.RooArgSet()
+            variables.add(self.nuisance_parameters)
+            variables.add(self.global_observables)
+            variables.add(self.pois)
         else:
             raise ValueError(f"unknown variable type \"{variable_type}\"")
         if sort:
