@@ -1,4 +1,6 @@
+from quickstats.components.workspaces.xml_ws_base import XMLWSBase, WSObjectType, XMLAttribType
 from quickstats.components.workspaces.sample import Sample
 from quickstats.components.workspaces.systematic import Systematic
 from quickstats.components.workspaces.asimov_handler import AsimovHandler
-from quickstats.components.workspaces.xml_ws_builder import XMLWSBuilder
\ No newline at end of file
+from quickstats.components.workspaces.xml_ws_builder import XMLWSBuilder
+from quickstats.components.workspaces.xml_ws_modifier import XMLWSModifier
\ No newline at end of file
