@@ -19,6 +19,10 @@ def compile_macros(macros:Optional[Union[str, List[str]]]=None):
         macros = macros.split(',')
     from quickstats.utils.root_utils import compile_macro
     for macro in macros:
+        if (macro == "FlexibleInterpVarMkII") and (quickstats.root_version >= (6, 26, 0)):
+            quickstats._PRINT_.info("INFO: Skip compiling macro \"FlexibleInterpVarMkII\" which is "
+                                    "deprecated since ROOT 6.26/00")
+            continue
         compile_macro(macro)
         
 def get_all_macros():
@@ -34,4 +38,14 @@ def get_all_macros():
 
 
 def set_verbosity(verbosity:Union[str, int]="INFO"):
-    quickstats._PRINT_.verbosity = verbosity
\ No newline at end of file
+    quickstats._PRINT_.verbosity = verbosity
+    
+    
+def get_root_version():
+    from quickstats.root_checker import ROOTChecker, ROOTVersion
+    try:
+        root_config_cmd = ROOTChecker.get_root_config_cmd()
+        root_version = ROOTChecker.get_installed_root_version(root_config_cmd)
+    except:
+        root_version = ROOTVersion((0, 0, 0))
+    return root_version
\ No newline at end of file
