@@ -7,8 +7,10 @@ from .score_distribution_plot import score_distribution_plot, score_distribution
 from .test_statistic_distribution_plot import TestStatisticDistributionPlot
 from .upper_limit_1D_plot import UpperLimit1DPlot
 from .upper_limit_2D_plot import UpperLimit2DPlot
+from .upper_limit_3D_plot import UpperLimit3DPlot
 from .upper_limit_benchmark_plot import UpperLimitBenchmarkPlot
 from .likelihood_1D_plot import Likelihood1DPlot
+from .likelihood_2D_plot import Likelihood2DPlot
 from .pdf_distribution_plot import PdfDistributionPlot
 from .correlation_plot import CorrelationPlot
 
