@@ -79,6 +79,23 @@ def load_macro(name:str):
                            "Please recompile by typing \"quickstats compile\".")
     return result
 
+def get_macro_dir(name:str):
+    return os.path.join(quickstats.macro_path, 'macros', name)
+
+def get_macro_TClass(name:str):
+    if not getattr(ROOT, name):
+        raise RuntimeError(f"class {name} is not loaded into ROOT yet")    
+    cls = ROOT.TClass.GetClass(name)
+    macro_dir = get_macro_dir(name)
+    macro_decl_file = os.path.join(f"{macro_dir}/{name}.h")
+    macro_impl_file = os.path.join(f"{macro_dir}/{name}.cxx")
+    if not os.path.exists(macro_decl_file):
+        raise FileNotFoundError(f"decl file {macro_decl_file} for the macro \"{name}\" not found")
+    if not os.path.exists(macro_impl_file):
+        raise FileNotFoundError(f"impl file {macro_impl_file} for the macro \"{name}\" not found")        
+    cls.SetDeclFile(macro_decl_file, 0)
+    cls.SetImplFileName(macro_impl_file)
+    return cls
 
 def print_resource_used(start):
     proc_info = ROOT.ProcInfo_t()
